@@ -1,4 +1,6 @@
-from __future__ import absolute_import
+__all__ = ('RGFClassifier', 'RGFRegressor',
+           'FastRGFClassifier', 'FastRGFRegressor')
+
 
 import os
 
@@ -6,9 +8,5 @@ from rgf.rgf_model import RGFRegressor, RGFClassifier
 from rgf.fastrgf_model import FastRGFRegressor, FastRGFClassifier
 
 
-__all__ = ('RGFClassifier', 'RGFRegressor',
-           'FastRGFClassifier', 'FastRGFRegressor')
-
-
-with open(os.path.join(os.path.dirname(__file__), 'VERSION')) as _f:
+with open(os.path.join(os.path.abspath(os.path.dirname(__file__)), 'VERSION')) as _f:
     __version__ = _f.read().strip()
